@@ -49,17 +49,31 @@ Session::checkLoginUser();
 
 /** @global array $CFG_GLPI */
 
+$append_params = [
+    "checkavailability" => "checkavailability",
+];
+
 if (isset($_POST['users_id']) && ($_POST['users_id'] > 0)) {
-      $rand = mt_rand();
-      echo "<a href='#' title=\"" . __s('Availability') . "\" data-bs-toggle='modal' data-bs-target='#planningcheck$rand'>";
-      echo "<i class='far fa-calendar-alt'></i>";
-      echo "<span class='sr-only'>" . __('Availability') . "</span>";
-      echo "</a>";
-      Ajax::createIframeModalWindow(
-          'planningcheck' . $rand,
-          $CFG_GLPI["root_doc"] .
-                                          "/front/planning.php?checkavailability=checkavailability" .
-                                          "&itemtype=User&users_id=" . $_POST['users_id'],
-          ['title'  => __('Availability')]
-      );
+    $append_params["itemtype"] = User::class;
+    $append_params[User::getForeignKeyField()] = $_POST['users_id'];
+} elseif (
+    isset($_POST['parent_itemtype']) && class_exists($_POST['parent_itemtype'])
+    && isset($_POST['parent_items_id']) && ($_POST['parent_items_id'] > 0)
+    && isset($_POST['parent_fk_field']) && ($_POST['parent_fk_field'] != '')
+) {
+    $append_params["itemtype"] = $_POST['parent_itemtype'];
+    $append_params[$_POST['parent_fk_field']] = $_POST['parent_items_id'];
+}
+
+if (count($append_params) > 1) {
+    $rand = mt_rand();
+    echo "<a href='#' title=\"" . __s('Availability') . "\" data-bs-toggle='modal' data-bs-target='#planningcheck$rand'>";
+    echo "<i class='far fa-calendar-alt'></i>";
+    echo "<span class='sr-only'>" . __('Availability') . "</span>";
+    echo "</a>";
+    Ajax::createIframeModalWindow(
+        'planningcheck' . $rand,
+        $CFG_GLPI["root_doc"] . "/front/planning.php?" . Toolbox::append_params($append_params),
+        ['title'  => __('Availability')]
+    );
 }
