@@ -1,13 +1,15 @@
 <?php
+
 /**
  * ---------------------------------------------------------------------
+ *
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
- * based on GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ * @copyright 2015-2022 Teclib' and contributors.
+ * @copyright 2003-2014 by the INDEPNET Development Team.
+ * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
  * ---------------------------------------------------------------------
  *
@@ -15,31 +17,35 @@
  *
  * This file is part of GLPI.
  *
- * GLPI is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * GLPI is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ *
  * ---------------------------------------------------------------------
  */
 
-include ('../inc/includes.php');
+include('../inc/includes.php');
 
 Session::checkSeveralRightsOr(['notification' => READ,
-                                    'config'       => UPDATE]);
+    'config'       => UPDATE
+]);
 
 Html::header(_n('Notification', 'Notifications', Session::getPluralNumber()), $_SERVER['PHP_SELF'], "config", "notification");
 
-if (!Session::haveRight("config", READ)
-   && Session::haveRight("notification", READ)) {
-   Html::redirect($CFG_GLPI["root_doc"].'/front/notification.php');
+if (
+    !Session::haveRight("config", READ)
+    && Session::haveRight("notification", READ)
+) {
+    Html::redirect($CFG_GLPI["root_doc"] . '/front/notification.php');
 }
 
 $settingconfig = new NotificationSettingConfig();
@@ -48,10 +54,10 @@ $settingconfig = new NotificationSettingConfig();
 Notification_NotificationTemplate::getModes();
 
 if (count($_POST)) {
-   $settingconfig->update($_POST);
-   Html::back();
+    $settingconfig->update($_POST);
+    Html::back();
 }
 
-$settingconfig->showForm();
+$settingconfig->showConfigForm();
 
 Html::footer();
