@@ -736,19 +736,16 @@ class Auth extends CommonGLPI
         if ($login_auth == 'local') {
             $authtype = self::DB_GLPI;
             $this->user->fields["authtype"] = self::DB_GLPI;
-        } else if (strstr($login_auth, '-')) {
-            $auths = explode('-', $login_auth);
-            $this->user->fields["auths_id"] = $auths[1];
-            if ($auths[0] == 'ldap') {
+        } else if (preg_match('/^(?<type>ldap|mail|external)-(?<id>\d+)$/', $login_auth, $auth_matches)) {
+            $this->user->fields["auths_id"] = (int)$auth_matches['id'];
+            if ($auth_matches['type'] == 'ldap') {
                 $authtype = self::LDAP;
-                $this->user->fields["authtype"] = self::LDAP;
-            } else if ($auths[0] == 'mail') {
+            } else if ($auth_matches['type'] == 'mail') {
                 $authtype = self::MAIL;
-                $this->user->fields["authtype"] = self::MAIL;
-            } else if ($auths[0] == 'external') {
+            } else if ($auth_matches['type'] == 'external') {
                 $authtype = self::EXTERNAL;
-                $this->user->fields["authtype"] = self::EXTERNAL;
             }
+            $this->user->fields['authtype'] = $authtype;
         }
         if (!$noauto && ($authtype = self::checkAlternateAuthSystems())) {
             if (
@@ -1678,7 +1675,7 @@ class Auth extends CommonGLPI
         echo "</tr>";
 
         echo "<tr class='tab_bg_2'>";
-        echo "<td class='center'>" . __('Administrative number') . "</td>";
+        echo "<td class='center'>" . _x('user', 'Administrative number') . "</td>";
         echo "<td><input type='text' class='form-control' name='registration_number_ssofield' value='" .
                   $CFG_GLPI['registration_number_ssofield'] . "'>";
         echo "</td>";
