@@ -1034,7 +1034,9 @@ class CommonGLPI implements CommonGLPIInterface
             if ($this instanceof CommonITILObject) {
                 echo "<h3 class='navigationheader-title strong d-flex align-items-center'>";
                 echo "<i class='" . $this->getIcon() . " me-1'></i>";
-                echo $this->getNameID();
+                echo $this->getNameID([
+                    'forceid' => $this instanceof CommonITILObject
+                ]);
                 echo "</h3>";
             }
 
