@@ -44,7 +44,7 @@ class KnowbaseItem_KnowbaseItemCategory extends CommonDBRelation
     public static $itemtype_1          = 'KnowbaseItem';
     public static $items_id_1          = 'knowbaseitems_id';
     public static $itemtype_2          = 'KnowbaseItemCategory';
-    public static $items_id_2          = 'Knowbaseitemcategories_id';
+    public static $items_id_2          = 'knowbaseitemcategories_id';
     public static $checkItem_2_Rights  = self::HAVE_VIEW_RIGHT_ON_ITEM;
 
    // From CommonDBTM
