@@ -373,6 +373,14 @@ class NetworkEquipment extends CommonDBTM
             'condition'          => ['is_itemgroup' => 1]
         ];
 
+        $tab[] = [
+            'id'                 => '72',
+            'table'              => 'glpi_autoupdatesystems',
+            'field'              => 'name',
+            'name'               => AutoUpdateSystem::getTypeName(1),
+            'datatype'           => 'dropdown'
+        ];
+
         $tab[] = [
             'id'                 => '19',
             'table'              => $this->getTable(),
