@@ -265,6 +265,7 @@ class Printer extends CommonDBTM
                 Certificate_Item::class,
                 Computer_Item::class,
                 Item_Project::class,
+                Printer_CartridgeInfo::class
             ]
         );
 
@@ -433,6 +434,14 @@ class Printer extends CommonDBTM
             'datatype'           => 'dropdown'
         ];
 
+        $tab[] = [
+            'id'                 => '72',
+            'table'              => 'glpi_autoupdatesystems',
+            'field'              => 'name',
+            'name'               => AutoUpdateSystem::getTypeName(1),
+            'datatype'           => 'dropdown'
+        ];
+
         $tab[] = [
             'id'                 => '19',
             'table'              => $this->getTable(),
